# CCMR

## Original code

[https://github.com/cv-stuttgart/CCMR](https://github.com/cv-stuttgart/CCMR)

## Code license

See [LICENSE](LICENSE).

## Pretrained weights license

Not specified.

## Citation

```
@inproceedings{jahedi2024ccmr,
  title={CCMR: High Resolution Optical Flow Estimation via Coarse-to-Fine Context-Guided Motion Reasoning},
  author={Jahedi, Azin and Luz, Maximilian and Rivinius, Marc and Bruhn, Andr{\'e}s},
  booktitle={Proceedings of the IEEE/CVF Winter Conference on Applications of Computer Vision},
  pages={6899--6908},
  year={2024}
}
```